==> paraview-5.12.0-6-x86_64.pkg.tar.zst: opt/paraview/lib/cmake/paraview/CFSReader-vtk-module-properties.cmake <==
set(_vtk_module_import_prefix "${CMAKE_CURRENT_LIST_DIR}")
get_filename_component(_vtk_module_import_prefix "${_vtk_module_import_prefix}" DIRECTORY)
get_filename_component(_vtk_module_import_prefix "${_vtk_module_import_prefix}" DIRECTORY)
get_filename_component(_vtk_module_import_prefix "${_vtk_module_import_prefix}" DIRECTORY)
set_property(TARGET "CFSReader::Reader" PROPERTY "INTERFACE_vtk_module_exclude_wrap" "FALSE")
set_property(TARGET "CFSReader::Reader" PROPERTY "INTERFACE_vtk_module_depends" "VTK::CommonCore;VTK::CommonMisc;VTK::CommonExecutionModel;VTK::hdf5")
set_property(TARGET "CFSReader::Reader" PROPERTY "INTERFACE_vtk_module_private_depends" "VTK::vtksys")
set_property(TARGET "CFSReader::Reader" PROPERTY "INTERFACE_vtk_module_optional_depends" "")
set_property(TARGET "CFSReader::Reader" PROPERTY "INTERFACE_vtk_module_implements" "")
set_property(TARGET "CFSReader::Reader" PROPERTY "INTERFACE_vtk_module_implementable" "FALSE")
set_property(TARGET "CFSReader::Reader" PROPERTY "INTERFACE_vtk_module_library_name" "vtkCFSReader")
set_property(TARGET "CFSReader::Reader" PROPERTY "INTERFACE_vtk_module_headers" "${_vtk_module_import_prefix}/include/paraview/ParaView_paraview_plugins/vtkCFSReader.h;${_vtk_module_import_prefix}/include/paraview/ParaView_paraview_plugins/vtkCFSReaderModule.h")
set_property(TARGET "CFSReader::Reader" PROPERTY "INTERFACE_vtk_module_hierarchy" "${_vtk_module_import_prefix}/lib/paraview/plugins/CFSReader/vtk/hierarchy/CFSReader/vtkCFSReader-hierarchy.txt")
unset(_vtk_module_import_prefix)

==> paraview-5.13.1-7-x86_64.pkg.tar.zst: opt/paraview/lib/cmake/paraview/CFSReader-vtk-module-properties.cmake <==
set(_vtk_module_import_prefix "${CMAKE_CURRENT_LIST_DIR}")
get_filename_component(_vtk_module_import_prefix "${_vtk_module_import_prefix}" DIRECTORY)
get_filename_component(_vtk_module_import_prefix "${_vtk_module_import_prefix}" DIRECTORY)
get_filename_component(_vtk_module_import_prefix "${_vtk_module_import_prefix}" DIRECTORY)
set_property(TARGET "CFSReader::Reader" PROPERTY "INTERFACE_vtk_module_exclude_wrap" "FALSE")
set_property(TARGET "CFSReader::Reader" PROPERTY "INTERFACE_vtk_module_include_marshal" "FALSE")
set_property(TARGET "CFSReader::Reader" PROPERTY "INTERFACE_vtk_module_depends" "VTK::CommonCore;VTK::CommonMisc;VTK::CommonExecutionModel;VTK::hdf5")
set_property(TARGET "CFSReader::Reader" PROPERTY "INTERFACE_vtk_module_private_depends" "VTK::vtksys")
set_property(TARGET "CFSReader::Reader" PROPERTY "INTERFACE_vtk_module_optional_depends" "")
set_property(TARGET "CFSReader::Reader" PROPERTY "INTERFACE_vtk_module_implements" "")
set_property(TARGET "CFSReader::Reader" PROPERTY "INTERFACE_vtk_module_implementable" "FALSE")
set_property(TARGET "CFSReader::Reader" PROPERTY "INTERFACE_vtk_module_library_name" "vtkCFSReader")
set_property(TARGET "CFSReader::Reader" PROPERTY "INTERFACE_vtk_module_headers" "${_vtk_module_import_prefix}/include/paraview/ParaView_paraview_plugins/vtkCFSReader.h")
set_property(TARGET "CFSReader::Reader" PROPERTY "INTERFACE_vtk_module_hierarchy" "${_vtk_module_import_prefix}/lib/paraview/plugins/CFSReader/vtk/hierarchy/CFSReader/vtkCFSReader-hierarchy.txt")
unset(_vtk_module_import_prefix)
